Package: nleqslv
Version: 3.3.5
Title: Solve Systems of Nonlinear Equations
Date: 2023-11-25
Author: Berend Hasselman
Maintainer: Berend Hasselman <bhh@xs4all.nl>
Description: Solve a system of nonlinear equations using a Broyden or a Newton method
             with a choice of global strategies such as line search and trust region.
             There are options for using a numerical or user supplied Jacobian,
             for specifying a banded numerical Jacobian and for allowing
             a singular or ill-conditioned Jacobian.
License: GPL (>= 2)
NeedsCompilation: yes
Packaged: 2023-11-24 19:45:26 UTC; berendhasselman
Repository: CRAN
Date/Publication: 2023-11-26 23:30:14 UTC
Built: R 4.5.3; x86_64-apple-darwin23.6.0; 2026-04-11 22:38:25 UTC; unix
